@@ -48,11 +48,9 @@ xl_xyz_series_update (GogObject *obj)
 	int x_len = 0, z_len = 0;
 
 	if (series->values[1].data != NULL)
-		z_len = go_data_vector_get_len (
-			GO_DATA_VECTOR (series->values[1].data));
+		z_len = go_data_get_vector_size (series->values[1].data);
 	if (series->values[0].data != NULL)
-		x_len = go_data_vector_get_len (
-			GO_DATA_VECTOR (series->values[0].data));
+		x_len = go_data_get_vector_size (series->values[0].data);
 	else
 		x_len = z_len;
 	series->num_elements = MIN (x_len, z_len);
@@ -65,9 +63,10 @@ xl_xyz_series_update (GogObject *obj)
 }
 
 static void
-xl_xyz_series_init_style (GogStyledObject *gso, GogStyle *style)
+xl_xyz_series_init_style (GogStyledObject *gso, GOStyle *style)
 {
 	series_parent_klass->init_style (gso, style);
+	style->interesting_fields = 0;  /* a quick hack to hide the style in the guru */
 }
 
 static void
@@ -83,7 +82,7 @@ xl_xyz_series_class_init (GogStyledObjectClass *gso_klass)
 
 GSF_DYNAMIC_CLASS (XLXYZSeries, xl_xyz_series,
 	xl_xyz_series_class_init, NULL,
-	GOG_SERIES_TYPE)
+	GOG_TYPE_SERIES)
 
 /*****************************************************************************/
 
@@ -108,16 +107,13 @@ xl_xyz_plot_update (GogObject *obj)
 	/* for first series, num_elements is used for zaxis, so we
 	can't use it to evaluate model->columns */
 	if (series->values[1].data != NULL) {
-		model->columns = go_data_vector_get_len (
-			GO_DATA_VECTOR (series->values[1].data));
+		model->columns = go_data_get_vector_size (series->values[1].data);
 		if (series->values[0].data != NULL)
-				model->rows = go_data_vector_get_len (
-				GO_DATA_VECTOR (series->values[0].data));
+			model->rows = go_data_get_vector_size (series->values[0].data);
 		if (model->rows < model->columns)
 			model->columns = model->rows;
 	} else if (series->values[0].data != NULL)
-		model->columns = go_data_vector_get_len (
-			GO_DATA_VECTOR (series->values[0].data));
+		model->columns = go_data_get_vector_size (series->values[0].data);
 	model->rows = 1;
 
 	for (ptr = ptr->next; ptr != NULL; ptr = ptr->next) {
@@ -127,8 +123,7 @@ xl_xyz_plot_update (GogObject *obj)
 		if (series->num_elements > model->columns)
 			model->columns = series->num_elements;
 		model->rows++;
-		go_data_vector_get_minmax (GO_DATA_VECTOR (
-			series->values[1].data), &tmp_min, &tmp_max);
+		go_data_get_bounds (series->values[1].data, &tmp_min, &tmp_max);
 		if (zmin > tmp_min) zmin = tmp_min;
 		if (zmax < tmp_max) zmax = tmp_max;
 	}
@@ -146,7 +141,7 @@ xl_xyz_plot_update (GogObject *obj)
 	gog_axis_bound_changed (model->base.axis[GOG_AXIS_Y], obj);
 }
 
-static GODataVector *
+static GOData *
 get_y_vector (GogPlot *plot)
 {
 	GSList *ptr;
@@ -163,24 +158,25 @@ get_y_vector (GogPlot *plot)
 
 		if (!gog_series_is_valid (GOG_SERIES (series)))
 			continue;
-		(*y_labels) [i] = go_data_scalar_get_str (GO_DATA_SCALAR (
-				series->values[-1].data));
+		(*y_labels) [i] = (series->values[-1].data)?
+				go_data_get_scalar_string (series->values[-1].data):
+				g_strdup_printf("S%d", i + 1); /* excel like labels */
 	}
 
-	return GO_DATA_VECTOR (go_data_vector_str_new (*y_labels, i, NULL));
+	return GO_DATA (go_data_vector_str_new (*y_labels, i, g_free));
 }
 
 static GOData *
-xl_xyz_plot_axis_get_bounds (GogPlot *plot, GogAxisType axis, 
-				GogPlotBoundInfo * bounds)
+xl_xyz_plot_axis_get_bounds (GogPlot *plot, GogAxisType axis,
+			     GogPlotBoundInfo * bounds)
 {
 	GogXYZPlot *xyz = GOG_XYZ_PLOT (plot);
-	GODataVector *vec = NULL;
+	GOData *vec = NULL;
 	GOFormat *fmt;
 
 	if (axis == GOG_AXIS_X) {
 		XLXYZSeries *series = XL_XYZ_SERIES (plot->series->data);
-		vec = GO_DATA_VECTOR (series->values[0].data);
+		vec = series->values[0].data;
 		fmt = xyz->x.fmt;
 	} else if (axis == GOG_AXIS_Y) {
 		if (!xyz->rows)
@@ -201,8 +197,8 @@ xl_xyz_plot_axis_get_bounds (GogPlot *plot, GogAxisType axis,
 	bounds->logical.maxima = go_nan;
 	bounds->is_discrete    = TRUE;
 	bounds->center_on_ticks = TRUE;
-	bounds->val.maxima = (axis == GOG_AXIS_X)? 
-		xyz->columns: 
+	bounds->val.maxima = (axis == GOG_AXIS_X)?
+		xyz->columns:
 		xyz->rows;
 	return (GOData*) vec;
 }
@@ -223,7 +219,7 @@ xl_contour_plot_build_matrix (GogXYZPlot const *plot,
 	unsigned nticks;
 	double x[2], val;
 	GogSeries *series = NULL;
-	GODataVector *vec;
+	GOData *vec;
 	unsigned n = plot->rows * plot->columns;
 	double *data, minimum, maximum;
 	unsigned max;
@@ -246,12 +242,12 @@ xl_contour_plot_build_matrix (GogXYZPlot const *plot,
 		series = ptr->data;
 		if (!gog_series_is_valid (GOG_SERIES (series)))
 			continue;
-		vec = GO_DATA_VECTOR (series->values[1].data);
-		length = go_data_vector_get_len (vec);
+		vec = series->values[1].data;
+		length = go_data_get_vector_size (vec);
 		for (j = 0; j < plot->columns; j++) {
 			/* The vector might be too short, excel is so ugly ;-) */
 			val = (j < length)? gog_axis_map_to_view (map,
-					go_data_vector_get_value (vec, j)): 0.;
+					go_data_get_vector_value (vec, j)): 0.;
 			/* This is an excel compatible plot, so let's be compatible */
 			if (val == go_nan || !go_finite (val))
 				val = 0.;
@@ -303,7 +299,7 @@ xl_contour_plot_class_init (GogContourPlotClass *klass)
 
 	{
 		static GogSeriesDimDesc dimensions[] = {
-			{ N_("X"), GOG_SERIES_REQUIRED, FALSE,
+			{ N_("X"), GOG_SERIES_SUGGESTED, FALSE,
 			  GOG_DIM_LABEL, GOG_MS_DIM_CATEGORIES },
 			{ N_("Z"), GOG_SERIES_REQUIRED, FALSE,
 			  GOG_DIM_VALUE, GOG_MS_DIM_VALUES },
@@ -313,6 +309,7 @@ xl_contour_plot_class_init (GogContourPlotClass *klass)
 		gog_plot_klass->desc.series.style_fields = 0;
 	}
 	/* Fill in GogPlotClass methods */
+	gog_plot_klass->desc.num_series_max = G_MAXINT;
 	gog_plot_klass->axis_get_bounds	= xl_xyz_plot_axis_get_bounds;
 	gog_plot_klass->series_type = xl_xyz_series_get_type();
 
@@ -327,7 +324,7 @@ xl_contour_plot_init (XLContourPlot *contour)
 
 GSF_DYNAMIC_CLASS (XLContourPlot, xl_contour_plot,
 	xl_contour_plot_class_init, xl_contour_plot_init,
-	GOG_CONTOUR_PLOT_TYPE)
+	GOG_TYPE_CONTOUR_PLOT)
 
 /*****************************************************************************/
 
@@ -342,7 +339,7 @@ xl_surface_plot_build_matrix (GogXYZPlot const *plot,
 	unsigned i, j, length;
 	double val;
 	GogSeries *series = NULL;
-	GODataVector *vec;
+	GOData *vec;
 	unsigned n = plot->rows * plot->columns;
 	double *data;
 	GSList *ptr;
@@ -352,11 +349,11 @@ xl_surface_plot_build_matrix (GogXYZPlot const *plot,
 		series = ptr->data;
 		if (!gog_series_is_valid (GOG_SERIES (series)))
 			continue;
-		vec = GO_DATA_VECTOR (series->values[1].data);
-		length = go_data_vector_get_len (vec);
+		vec = series->values[1].data;
+		length = go_data_get_vector_size (vec);
 		for (j = 0; j < plot->columns; j++) {
 			/* The vector might be too short, excel is so ugly ;-) */
-			val = (j < length)? go_data_vector_get_value (vec, j): 0.;
+			val = (j < length)? go_data_get_vector_value (vec, j): 0.;
 			/* This is an excel compatible plot, so let's be compatible */
 			if (val == go_nan || !go_finite (val))
 				val = 0.;
@@ -395,16 +392,17 @@ xl_surface_plot_class_init (GogSurfacePlotClass *klass)
 
 	{
 		static GogSeriesDimDesc dimensions[] = {
-			{ N_("X"), GOG_SERIES_REQUIRED, FALSE,
+			{ N_("X"), GOG_SERIES_SUGGESTED, FALSE,
 			  GOG_DIM_LABEL, GOG_MS_DIM_CATEGORIES },
 			{ N_("Z"), GOG_SERIES_REQUIRED, FALSE,
 			  GOG_DIM_VALUE, GOG_MS_DIM_VALUES },
 		};
 		gog_plot_klass->desc.series.dim = dimensions;
 		gog_plot_klass->desc.series.num_dim = G_N_ELEMENTS (dimensions);
-		gog_plot_klass->desc.series.style_fields = 0;
+		gog_plot_klass->desc.series.style_fields = GO_STYLE_LINE | GO_STYLE_FILL;
 	}
 	/* Fill in GogPlotClass methods */
+	gog_plot_klass->desc.num_series_max = G_MAXINT;
 	gog_plot_klass->axis_get_bounds	= xl_xyz_plot_axis_get_bounds;
 	gog_plot_klass->series_type = xl_xyz_series_get_type();
 
@@ -419,5 +417,5 @@ xl_surface_plot_init (XLSurfacePlot *contour)
 
 GSF_DYNAMIC_CLASS (XLSurfacePlot, xl_surface_plot,
 	xl_surface_plot_class_init, xl_surface_plot_init,
-	GOG_SURFACE_PLOT_TYPE)
+	GOG_TYPE_SURFACE_PLOT)
 
